@@ -37,9 +37,12 @@ def run(file: str = __DEFAULT_FILE__) -> dict:
         try:
             for entry in parse(package):
                 try:
-                    condition = LooseVersion(str(entry['version'])) > LooseVersion(str(get_version(package)))
-                except TypeError as e:
                     condition = version_compare(str(entry['version']), str(get_version(package))) > 0
+                except e:
+                    try:
+                        condition = LooseVersion(str(entry['version'])) > LooseVersion(str(get_version(package)))
+                    except e:
+                        condition = False
                 if condition:
                     database = _get_database(file)
                     database[package] = entry['version']
